@@ -21,6 +21,8 @@ describe "Architecture fact" do
     ["Gentoo","i586"] => "x86",
     ["Gentoo","i686"] => "x86",
     ["Gentoo","pentium"] => "x86",
+    ["windows","i386"] => "x86",
+    ["windows","x64"] => "x64",
   }
   generic_archs = Hash.new
   generic_archs = {
