@@ -10,13 +10,13 @@ describe "lsbdistdescription fact" do
         Facter.fact(:kernel).stubs(:value).returns kernel
       end
 
-      it "should return the description through lsb_release -d -s" do
-        Facter::Util::Resolution.stubs(:exec).with('lsb_release -d -s').returns '"Gentoo Base System release 2.1"'
+      it "should return the description through lsb_release -d -s 2>/dev/null" do
+        Facter::Util::Resolution.stubs(:exec).with('lsb_release -d -s 2>/dev/null').returns '"Gentoo Base System release 2.1"'
         Facter.fact(:lsbdistdescription).value.should == 'Gentoo Base System release 2.1'
       end
 
       it "should return nil if lsb_release is not installed" do
-        Facter::Util::Resolution.stubs(:exec).with('lsb_release -d -s').returns nil
+        Facter::Util::Resolution.stubs(:exec).with('lsb_release -d -s 2>/dev/null').returns nil
         Facter.fact(:lsbdistdescription).value.should be_nil
       end
     end
